# Github Actions configuration plugin

This plugin is used for [GitHub Actions](https://github.com/features/actions) configuration projects when `PROGRAMMING_LANGUAGE` is set to `github_actions`.

This plugin is dedicated to managing GitHub Actions and workflows and is expected to run within this CI system.

## Prerequisites
This plugin expects the [GitHub CLI](https://cli.github.com) to be installed and available from the path. 

## Release
The plugin carries out the same git actions as the [CI](./CI.MD) plugin but also performs extra GitHub actions such as release creation, etc.

## Documentation
The plugin does not generate any documentation.